@@ -32,35 +32,27 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_BITFIELD_MESSAGE_VALIDATOR_H_
-#define _D_BT_BITFIELD_MESSAGE_VALIDATOR_H_
+#ifndef D_BT_BITFIELD_MESSAGE_VALIDATOR_H
+#define D_BT_BITFIELD_MESSAGE_VALIDATOR_H
 
 #include "BtMessageValidator.h"
-#include "BtBitfieldMessage.h"
-#include "bittorrent_helper.h"
 
 namespace aria2 {
 
+class BtBitfieldMessage;
+
 class BtBitfieldMessageValidator : public BtMessageValidator {
 private:
   const BtBitfieldMessage* message_;
   size_t numPiece_;
 public:
   BtBitfieldMessageValidator(const BtBitfieldMessage* message,
-                             size_t numPiece):
-    message_(message),
-    numPiece_(numPiece) {}
+                             size_t numPiece);
+  ~BtBitfieldMessageValidator();
 
-  virtual void validate()
-  {
-    bittorrent::checkBitfield(message_->getBitfield(),
-                              message_->getBitfieldLength(),
-                              numPiece_);
-  }
+  virtual void validate();
 };
 
-typedef SharedHandle<BtBitfieldMessageValidator> BtBitfieldMessageValidatorHandle;
-
 } // namespace aria2
 
-#endif // _D_BT_BITFIELD_MESSAGE_VALIDATOR_H_
+#endif // D_BT_BITFIELD_MESSAGE_VALIDATOR_H
