@@ -110,7 +110,10 @@ Cookie& Cookie::operator=(const Cookie& c)
 
 std::string Cookie::toString() const
 {
-  return strconcat(name_, '=', value_);
+  std::string s = name_;
+  s += "=";
+  s += value_;
+  return s;
 }
 
 bool Cookie::match
@@ -144,7 +147,7 @@ std::string Cookie::toNsCookieFormat() const
 {
   std::stringstream ss;
   if(!hostOnly_) {
-    ss << A2STR::DOT_C;
+    ss << ".";
   }
   ss << domain_ << "\t";
   if(hostOnly_) {
