@@ -57,7 +57,8 @@
 namespace aria2 {
 
 CookieStorage::DomainEntry::DomainEntry(const std::string& domain)
- : key_(util::isNumericHost(domain)?domain:cookie::reverseDomainLevel(domain))
+  : key_(util::isNumericHost(domain)?domain:cookie::reverseDomainLevel(domain)),
+    lastAccessTime_(0)
 {}
 
 CookieStorage::DomainEntry::DomainEntry
@@ -360,7 +361,7 @@ bool CookieStorage::load(const std::string& filename, time_t now)
   char header[16]; // "SQLite format 3" plus \0
   size_t headlen;
   {
-    BufferedFile fp(filename, BufferedFile::READ);
+    BufferedFile fp(filename.c_str(), BufferedFile::READ);
     if(!fp) {
       A2_LOG_ERROR(fmt("Failed to open cookie file %s", filename.c_str()));
       return false;
@@ -402,7 +403,7 @@ bool CookieStorage::saveNsFormat(const std::string& filename)
   std::string tempfilename = filename;
   tempfilename += "__temp";
   {
-    BufferedFile fp(tempfilename, BufferedFile::WRITE);
+    BufferedFile fp(tempfilename.c_str(), BufferedFile::WRITE);
     if(!fp) {
       A2_LOG_ERROR(fmt("Cannot create cookie file %s", filename.c_str()));
       return false;
@@ -417,7 +418,7 @@ bool CookieStorage::saveNsFormat(const std::string& filename)
     if(fp.close() == EOF) {
       A2_LOG_ERROR(fmt("Failed to save cookies to %s", filename.c_str()));
       return false;
-    }  
+    }
   }
   if(File(tempfilename).renameTo(filename)) {
     return true;
