@@ -39,6 +39,9 @@
 
 namespace aria2 {
 
+class BackupConnectInfo;
+class ConnectCommand;
+
 class InitiateConnectionCommand : public AbstractCommand {
 protected:
   /**
@@ -64,6 +67,14 @@ protected:
   (const SharedHandle<Request>& req,
    const std::string& hostname,
    const SharedHandle<SocketCore>& socket);
+
+  SharedHandle<BackupConnectInfo> createBackupIPv4ConnectCommand
+  (const std::string& hostname, const std::string& ipaddr, uint16_t port,
+   Command* mainCommand);
+
+  void setupBackupConnection
+  (const std::string& hostname, const std::string& addr, uint16_t port,
+   ConnectCommand* c);
 public:
   InitiateConnectionCommand(cuid_t cuid, const SharedHandle<Request>& req,
                             const SharedHandle<FileEntry>& fileEntry,
