@@ -176,11 +176,11 @@ void MetalinkParserController::setURLOfResource(const std::string& url)
     return;
   }
   std::string u = uri::joinUri(baseUri_, url);
-  uri::UriStruct us;
-  if(uri::parse(us, u)) {
+  uri_split_result us;
+  if(uri_split(&us, u.c_str()) == 0) {
     tResource_->url = u;
     if(tResource_->type == MetalinkResource::TYPE_UNKNOWN) {
-      setTypeOfResource(us.protocol);
+      setTypeOfResource(uri::getFieldString(us, USR_SCHEME, u.c_str()));
     }
   } else {
     tResource_->url = url;
@@ -192,15 +192,14 @@ void MetalinkParserController::setTypeOfResource(const std::string& type)
   if(!tResource_) {
     return;
   }
-  if(type == MetalinkResource::FTP) {
+  if(type == "ftp") {
     tResource_->type = MetalinkResource::TYPE_FTP;
-  } else if(type == MetalinkResource::HTTP) {
+  } else if(type == "http") {
     tResource_->type = MetalinkResource::TYPE_HTTP;
-  } else if(type == MetalinkResource::HTTPS) {
+  } else if(type == "https") {
     tResource_->type = MetalinkResource::TYPE_HTTPS;
-  } else if(type == MetalinkResource::BITTORRENT) {
-    tResource_->type = MetalinkResource::TYPE_BITTORRENT;
-  } else if(type == MetalinkResource::TORRENT) { // Metalink4Spec
+  } else if(type == "bittorrent" || type == "torrent") {
+    // "torrent" is Metalink4Spec
     tResource_->type = MetalinkResource::TYPE_BITTORRENT;
   } else {
     tResource_->type = MetalinkResource::TYPE_NOT_SUPPORTED;
@@ -369,7 +368,7 @@ void MetalinkParserController::addHashOfChunkChecksumV4(const std::string& md)
   } else {
     cancelChunkChecksumTransactionV4();
   }
-#endif // ENABLE_MESSAGE_DIGEST  
+#endif // ENABLE_MESSAGE_DIGEST
 }
 
 void MetalinkParserController::commitChunkChecksumTransactionV4()
@@ -580,8 +579,7 @@ void MetalinkParserController::setURLOfMetaurl(const std::string& url)
 #endif // ENABLE_BITTORRENT
     {
       std::string u = uri::joinUri(baseUri_, url);
-      uri::UriStruct us;
-      if(uri::parse(us, u)) {
+      if(uri_split(NULL, u.c_str()) == 0) {
         tMetaurl_->url = u;
       } else {
         tMetaurl_->url = url;
