@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,49 +38,51 @@
 
 namespace aria2 {
 
-NetrcAuthResolver::NetrcAuthResolver():_ignoreDefault(false) {}
+NetrcAuthResolver::NetrcAuthResolver():ignoreDefault_(false) {}
 
-AuthConfigHandle NetrcAuthResolver::resolveAuthConfig(const std::string& hostname)
+SharedHandle<AuthConfig>
+NetrcAuthResolver::resolveAuthConfig(const std::string& hostname)
 {
-  if(_userDefinedAuthConfig.isNull()) {
+  if(!getUserDefinedAuthConfig()) {
     return findNetrcAuthenticator(hostname);
   } else {
-    return _userDefinedAuthConfig;
+    return getUserDefinedAuthConfig();
   }
 }
 
-AuthConfigHandle NetrcAuthResolver::findNetrcAuthenticator(const std::string& hostname) const
+SharedHandle<AuthConfig>
+NetrcAuthResolver::findNetrcAuthenticator(const std::string& hostname) const
 {
-  if(_netrc.isNull()) {
-    return _defaultAuthConfig;
+  if(!netrc_) {
+    return getDefaultAuthConfig();
   } else {
-    AuthenticatorHandle auth = _netrc->findAuthenticator(hostname);
-    if(auth.isNull()) {
-      return _defaultAuthConfig;
+    SharedHandle<Authenticator> auth = netrc_->findAuthenticator(hostname);
+    if(!auth) {
+      return getDefaultAuthConfig();
     } else {
-      if(_ignoreDefault && auth->getMachine() == "") {
-	return _defaultAuthConfig;
+      if(ignoreDefault_ && auth->getMachine().empty()) {
+        return getDefaultAuthConfig();
       } else {
-	return SharedHandle<AuthConfig>
-	  (new AuthConfig(auth->getLogin(), auth->getPassword()));
+        return SharedHandle<AuthConfig>
+          (new AuthConfig(auth->getLogin(), auth->getPassword()));
       }
     }
   }
 }
 
-void NetrcAuthResolver::setNetrc(const NetrcHandle& netrc)
+void NetrcAuthResolver::setNetrc(const SharedHandle<Netrc>& netrc)
 {
-  _netrc = netrc;
+  netrc_ = netrc;
 }
 
 void NetrcAuthResolver::ignoreDefault()
 {
-  _ignoreDefault = true;
+  ignoreDefault_ = true;
 }
 
 void NetrcAuthResolver::useDefault()
 {
-  _ignoreDefault = false;
+  ignoreDefault_ = false;
 }
 
 } // namespace aria2
