@@ -48,6 +48,8 @@ namespace aria2 {
 std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
 {
   std::vector<OptionHandler*> handlers;
+  static const std::string logLevels[] =
+    { V_DEBUG, V_INFO, V_NOTICE, V_WARN, V_ERROR };
   // General Options
   {
     OptionHandler* op(new BooleanOptionHandler
@@ -213,6 +215,16 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_ADVANCED);
     handlers.push_back(op);
   }
+  {
+    OptionHandler* op(new ParameterOptionHandler
+                      (PREF_CONSOLE_LOG_LEVEL,
+                       TEXT_CONSOLE_LOG_LEVEL,
+                       V_NOTICE,
+                       std::vector<std::string>
+                       (vbegin(logLevels), vend(logLevels))));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     OptionHandler* op(new BooleanOptionHandler
                       (PREF_DEFERRED_INPUT,
@@ -278,11 +290,12 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
   }
 #ifdef ENABLE_ASYNC_DNS
   {
-    OptionHandler* op(new BooleanOptionHandler
-                      (PREF_ENABLE_ASYNC_DNS6,
-                       TEXT_ENABLE_ASYNC_DNS6,
-                       A2_V_FALSE,
-                       OptionHandler::OPT_ARG));
+    // TODO Deprecated
+    OptionHandler* op(new DeprecatedOptionHandler(new BooleanOptionHandler
+                                                  (PREF_ENABLE_ASYNC_DNS6,
+                                                   TEXT_ENABLE_ASYNC_DNS6,
+                                                   NO_DEFAULT_VALUE,
+                                                   OptionHandler::OPT_ARG)));
     op->addTag(TAG_ADVANCED);
     op->setInitialOption(true);
     op->setChangeGlobalOption(true);
@@ -290,18 +303,6 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     handlers.push_back(op);
   }
 #endif // ENABLE_ASYNC_DNS
-  {
-    // TODO Deprecated
-    OptionHandler* op(new DeprecatedOptionHandler(new BooleanOptionHandler
-                                                  (PREF_ENABLE_DIRECT_IO,
-                                                   TEXT_ENABLE_DIRECT_IO,
-                                                   NO_DEFAULT_VALUE,
-                                                   OptionHandler::OPT_ARG)));
-    op->addTag(TAG_DEPRECATED);
-    op->addTag(TAG_ADVANCED);
-    op->addTag(TAG_FILE);
-    handlers.push_back(op);
-  }
 #if defined HAVE_MMAP || defined __MINGW32__
   {
     OptionHandler* op(new BooleanOptionHandler
@@ -472,13 +473,12 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     handlers.push_back(op);
   }
   {
-    const std::string params[] = { V_DEBUG, V_INFO, V_NOTICE, V_WARN, V_ERROR };
     OptionHandler* op(new ParameterOptionHandler
                       (PREF_LOG_LEVEL,
                        TEXT_LOG_LEVEL,
                        V_DEBUG,
                        std::vector<std::string>
-                       (vbegin(params), vend(params))));
+                       (vbegin(logLevels), vend(logLevels))));
     op->addTag(TAG_ADVANCED);
     op->setChangeGlobalOption(true);
     handlers.push_back(op);
@@ -717,6 +717,15 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     op->setChangeGlobalOption(true);
     handlers.push_back(op);
   }
+  {
+    OptionHandler* op(new NumberOptionHandler
+                      (PREF_SAVE_SESSION_INTERVAL,
+                       TEXT_SAVE_SESSION_INTERVAL,
+                       "0",
+                       0));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     OptionHandler* op(new BooleanOptionHandler
                       (PREF_SELECT_LEAST_USED_HOST,
@@ -779,11 +788,20 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     handlers.push_back(op);
   }
   {
-    OptionHandler* op(new LocalFilePathOptionHandler
+    OptionHandler* op(
+#ifdef HAVE_APPLETLS
+                      new DefaultOptionHandler
+                      (PREF_RPC_CERTIFICATE,
+                       TEXT_RPC_CERTIFICATE,
+                       NO_DEFAULT_VALUE)
+#else // HAVE_APPLETLS
+                      new LocalFilePathOptionHandler
                       (PREF_RPC_CERTIFICATE,
                        TEXT_RPC_CERTIFICATE,
                        NO_DEFAULT_VALUE,
-                       false));
+                       false)
+#endif
+        );
     op->addTag(TAG_RPC);
     handlers.push_back(op);
   }
@@ -2199,20 +2217,6 @@ std::vector<OptionHandler*> OptionHandlerFactory::createOptionHandlers()
     op->setChangeOptionForReserved(true);
     handlers.push_back(op);
   }
-  {
-    OptionHandler* op
-      (new DeprecatedOptionHandler(new NumberOptionHandler
-                                   (PREF_METALINK_SERVERS,
-                                    TEXT_METALINK_SERVERS,
-                                    NO_DEFAULT_VALUE,
-                                    1, -1,
-                                    'C'),
-                                   splitHandler));
-    op->addTag(TAG_DEPRECATED);
-    op->addTag(TAG_METALINK);
-    op->setInitialOption(true);
-    handlers.push_back(op);
-  }
   {
     OptionHandler* op(new DefaultOptionHandler
                       (PREF_METALINK_VERSION,
