@@ -45,6 +45,7 @@
 namespace aria2 {
 
 class Piece;
+class WrDiskCache;
 
 class Segment {
 public:
@@ -55,7 +56,7 @@ public:
   virtual size_t getIndex() const = 0;
 
   virtual int64_t getPosition() const = 0;
-  
+
   virtual int64_t getPositionToWrite() const = 0;
 
   virtual int32_t getLength() const = 0;
@@ -80,7 +81,7 @@ public:
 
 #endif // ENABLE_MESSAGE_DIGEST
 
-  virtual void clear() = 0;
+  virtual void clear(WrDiskCache* diskCache) = 0;
 
   virtual SharedHandle<Piece> getPiece() const = 0;
 
