@@ -57,6 +57,12 @@ private:
     {
       return value_ && !name_.empty();
     }
+
+    void reset()
+    {
+      value_.reset();
+      name_.clear();
+    }
   };
 
   std::stack<StateFrame> frameStack_;
@@ -74,7 +80,7 @@ public:
   // Pops StateFrame p from frameStack_ and add currentFrame_.value_
   // to p and currentFrame_ = p;
   void popArrayFrame();
-  
+
   void setCurrentFrameValue(const SharedHandle<ValueBase>& value);
 
   void setCurrentFrameName(const std::string& name);
@@ -87,6 +93,8 @@ public:
   }
 
   const std::string& getMethodName() const { return methodName_; }
+
+  void reset();
 };
 
 } // namespace rpc
