@@ -141,7 +141,7 @@ void showCandidates
   std::vector<std::pair<int, const Pref*> > cands;
   for(int i = 1, len = option::countOption(); i < len; ++i) {
     const Pref* pref = option::i2p(i);
-    const SharedHandle<OptionHandler>& h = parser->find(pref);
+    const OptionHandler* h = parser->find(pref);
     if(!h || h->isHidden()) {
       continue;
     }
@@ -160,8 +160,8 @@ void showCandidates
   }
   std::sort(cands.begin(), cands.end());
   int threshold = cands[0].first;
-  // threshold value 7 is borrowed from git, help.c.
-  if(threshold >= 7) {
+  // threshold value 12 is a magic value.
+  if(threshold > 12) {
     return;
   }
   global::cerr()->printf("\n");
@@ -175,6 +175,20 @@ void showCandidates
 
 } // namespace
 
+#ifdef __MINGW32__
+namespace {
+void optionNativeToUtf8(Option& op)
+{
+  for(size_t i = 1, len = option::countOption(); i < len; ++i) {
+    const Pref* pref = option::i2p(i);
+    if(op.definedLocal(pref) && !util::isUtf8(op.get(pref))) {
+      op.put(pref, nativeToUtf8(op.get(pref)));
+    }
+  }
+}
+} // namespace
+#endif // __MINGW32__
+
 void option_processing(Option& op, std::vector<std::string>& uris,
                        int argc, char* argv[])
 {
@@ -198,7 +212,7 @@ void option_processing(Option& op, std::vector<std::string>& uris,
       if(op.defined(PREF_HELP)) {
         std::string keyword;
         if(op.get(PREF_HELP).empty()) {
-          keyword = TAG_BASIC;
+          keyword = strHelpTag(TAG_BASIC);
         } else {
           keyword = op.get(PREF_HELP);
           if(util::startsWith(keyword, "--")) {
@@ -213,28 +227,27 @@ void option_processing(Option& op, std::vector<std::string>& uris,
         exit(error_code::FINISHED);
       }
     }
-
-    oparser->parseDefaultValues(op);
-
+    SharedHandle<Option> confOption(new Option());
+    oparser->parseDefaultValues(*confOption);
     if(!noConf) {
-      std::string cfname = 
+      std::string cfname =
         ucfname.empty() ?
         oparser->find(PREF_CONF_PATH)->getDefaultValue() : ucfname;
 
       if(File(cfname).isFile()) {
         std::stringstream ss;
         {
-          BufferedFile fp(cfname, BufferedFile::READ);
+          BufferedFile fp(cfname.c_str(), BufferedFile::READ);
           if(fp) {
             fp.transfer(ss);
           }
         }
         try {
-          oparser->parse(op, ss);
+          oparser->parse(*confOption, ss);
         } catch(OptionHandlerException& e) {
           global::cerr()->printf(_("Parse error in %s"), cfname.c_str());
           global::cerr()->printf("\n%s", e.stackTrace().c_str());
-          const SharedHandle<OptionHandler>& h = oparser->find(e.getPref());
+          const OptionHandler* h = oparser->find(e.getPref());
           if(h) {
             global::cerr()->printf(_("Usage:"));
             global::cerr()->printf("\n%s\n", h->getDescription());
@@ -249,33 +262,30 @@ void option_processing(Option& op, std::vector<std::string>& uris,
         global::cerr()->printf(_("Configuration file %s is not found."),
                                cfname.c_str());
         global::cerr()->printf("\n");
-        showUsage(TAG_HELP, oparser, global::cerr());
+        showUsage(strHelpTag(TAG_HELP), oparser, global::cerr());
         exit(error_code::UNKNOWN_ERROR);
       }
     }
     // Override configuration with environment variables.
-    overrideWithEnv(op, oparser, PREF_HTTP_PROXY, "http_proxy");
-    overrideWithEnv(op, oparser, PREF_HTTPS_PROXY, "https_proxy");
-    overrideWithEnv(op, oparser, PREF_FTP_PROXY, "ftp_proxy");
-    overrideWithEnv(op, oparser, PREF_ALL_PROXY, "all_proxy");
-    overrideWithEnv(op, oparser, PREF_NO_PROXY, "no_proxy");
+    overrideWithEnv(*confOption, oparser, PREF_HTTP_PROXY, "http_proxy");
+    overrideWithEnv(*confOption, oparser, PREF_HTTPS_PROXY, "https_proxy");
+    overrideWithEnv(*confOption, oparser, PREF_FTP_PROXY, "ftp_proxy");
+    overrideWithEnv(*confOption, oparser, PREF_ALL_PROXY, "all_proxy");
+    overrideWithEnv(*confOption, oparser, PREF_NO_PROXY, "no_proxy");
 
     // we must clear eof bit and seek to the beginning of the buffer.
     cmdstream.clear();
     cmdstream.seekg(0, std::ios::beg);
     // finaly let's parse and store command-iine options.
+    op.setParent(confOption);
     oparser->parse(op, cmdstream);
 #ifdef __MINGW32__
-    for(size_t i = 1, len = option::countOption(); i < len; ++i) {
-      const Pref* pref = option::i2p(i);
-      if(op.defined(pref) && !util::isUtf8(op.get(pref))) {
-        op.put(pref, nativeToUtf8(op.get(pref)));
-      }
-    }
+    optionNativeToUtf8(op);
+    optionNativeToUtf8(*confOption);
 #endif // __MINGW32__
   } catch(OptionHandlerException& e) {
     global::cerr()->printf("%s", e.stackTrace().c_str());
-    const SharedHandle<OptionHandler>& h = oparser->find(e.getPref());
+    const OptionHandler* h = oparser->find(e.getPref());
     if(h) {
       global::cerr()->printf(_("Usage:"));
       global::cerr()->printf("\n");
