@@ -7,6 +7,8 @@
 #include "Option.h"
 #include "FileEntry.h"
 #include "bittorrent_helper.h"
+#include "PieceStorage.h"
+#include "DiskAdaptor.h"
 
 namespace aria2 {
 
@@ -18,11 +20,11 @@ class BtPostDownloadHandlerTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testGetNextRequestGroups);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<Option> _option;
+  SharedHandle<Option> option_;
 public:
   void setUp()
   {
-    _option.reset(new Option());
+    option_.reset(new Option());
   }
 
   void testCanHandle_extension();
@@ -35,15 +37,16 @@ CPPUNIT_TEST_SUITE_REGISTRATION( BtPostDownloadHandlerTest );
 
 void BtPostDownloadHandlerTest::testCanHandle_extension()
 {
-  SharedHandle<DownloadContext> dctx(new DownloadContext(0, 0, "test.torrent"));
-  RequestGroup rg(_option);
+  SharedHandle<DownloadContext> dctx
+    (new DownloadContext(0, 0, A2_TEST_DIR"/test.torrent"));
+  RequestGroup rg(GroupId::create(), option_);
   rg.setDownloadContext(dctx);
 
   BtPostDownloadHandler handler;
 
   CPPUNIT_ASSERT(handler.canHandle(&rg));
 
-  dctx->getFirstFileEntry()->setPath("test.torrent2");
+  dctx->getFirstFileEntry()->setPath(A2_TEST_DIR"/test.torrent2");
   CPPUNIT_ASSERT(!handler.canHandle(&rg));
 }
 
@@ -51,7 +54,7 @@ void BtPostDownloadHandlerTest::testCanHandle_contentType()
 {
   SharedHandle<DownloadContext> dctx(new DownloadContext(0, 0, "test"));
   dctx->getFirstFileEntry()->setContentType("application/x-bittorrent");
-  RequestGroup rg(_option);
+  RequestGroup rg(GroupId::create(), option_);
   rg.setDownloadContext(dctx);
 
   BtPostDownloadHandler handler;
@@ -65,13 +68,14 @@ void BtPostDownloadHandlerTest::testCanHandle_contentType()
 void BtPostDownloadHandlerTest::testGetNextRequestGroups()
 {
   SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024, 0, "test.torrent"));
-  RequestGroup rg(_option);
+    (new DownloadContext(1024, 0, A2_TEST_DIR"/test.torrent"));
+  RequestGroup rg(GroupId::create(), option_);
   rg.setDownloadContext(dctx);
   rg.initPieceStorage();
+  rg.getPieceStorage()->getDiskAdaptor()->enableReadOnly();
 
   BtPostDownloadHandler handler;
-  std::deque<SharedHandle<RequestGroup> > groups;
+  std::vector<SharedHandle<RequestGroup> > groups;
   handler.getNextRequestGroups(groups, &rg);
   CPPUNIT_ASSERT_EQUAL((size_t)1, groups.size());
   CPPUNIT_ASSERT_EQUAL
