@@ -3,10 +3,9 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "DHTNode.h"
-#include "DHTUtil.h"
 #include "Exception.h"
-#include "Util.h"
-#include "bencode.h"
+#include "util.h"
+#include "bencode2.h"
 
 namespace aria2 {
 
@@ -32,21 +31,22 @@ void DHTAnnouncePeerReplyMessageTest::testGetBencodedMessage()
   SharedHandle<DHTNode> remoteNode(new DHTNode());
 
   unsigned char tid[DHT_TRANSACTION_ID_LENGTH];
-  DHTUtil::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
+  util::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
   std::string transactionID(&tid[0], &tid[DHT_TRANSACTION_ID_LENGTH]);
 
   DHTAnnouncePeerReplyMessage msg(localNode, remoteNode, transactionID);
-
+  msg.setVersion("A200");
   std::string msgbody = msg.getBencodedMessage();
 
-  BDE dict = BDE::dict();
-  dict["t"] = transactionID;
-  dict["y"] = BDE("r");
-  BDE rDict = BDE::dict();
-  rDict["id"] = BDE(localNode->getID(), DHT_ID_LENGTH);
-  dict["r"] = rDict;
+  Dict dict;
+  dict.put("t", transactionID);
+  dict.put("v", "A200");
+  dict.put("y", "r");
+  SharedHandle<Dict> rDict = Dict::g();
+  rDict->put("id", String::g(localNode->getID(), DHT_ID_LENGTH));
+  dict.put("r", rDict);
 
-  CPPUNIT_ASSERT_EQUAL(bencode::encode(dict), msgbody);
+  CPPUNIT_ASSERT_EQUAL(bencode2::encode(&dict), msgbody);
 }
 
 } // namespace aria2
