@@ -24,6 +24,7 @@ class DHTBucketTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testGetGoodNodes);
   CPPUNIT_TEST(testCacheNode);
   CPPUNIT_TEST(testDropNode);
+  CPPUNIT_TEST(testGetNode);
   CPPUNIT_TEST_SUITE_END();
 public:
   void setUp() {}
@@ -40,6 +41,7 @@ public:
   void testGetGoodNodes();
   void testCacheNode();
   void testDropNode();
+  void testGetNode();
 };
 
 
@@ -289,12 +291,14 @@ void DHTBucketTest::testSplit()
 
 }
 
-static void createID(unsigned char* id, unsigned char firstChar, unsigned char lastChar)
+namespace {
+void createID(unsigned char* id, unsigned char firstChar, unsigned char lastChar)
 {
   memset(id, 0, DHT_ID_LENGTH);
   id[0] = firstChar;
   id[DHT_ID_LENGTH-1] = lastChar;
 }
+} // namespace
 
 void DHTBucketTest::testAddNode()
 {
@@ -317,7 +321,7 @@ void DHTBucketTest::testAddNode()
   // nodes[0] is located at the tail of the bucket(least recent seen)
   nodes[0]->markBad();
   CPPUNIT_ASSERT(bucket.addNode(newNode));
-  CPPUNIT_ASSERT(bucket.getNodes().back() == newNode);
+  CPPUNIT_ASSERT(*bucket.getNodes().back() == *newNode);
 }
 
 void DHTBucketTest::testMoveToHead()
@@ -335,7 +339,7 @@ void DHTBucketTest::testMoveToHead()
     CPPUNIT_ASSERT(bucket.addNode(nodes[i]));
   }
   bucket.moveToHead(nodes[DHTBucket::K-1]);
-  CPPUNIT_ASSERT(bucket.getNodes().front() == nodes[DHTBucket::K-1]);
+  CPPUNIT_ASSERT(*bucket.getNodes().front() == *nodes[DHTBucket::K-1]);
 }
 
 void DHTBucketTest::testMoveToTail()
@@ -353,7 +357,7 @@ void DHTBucketTest::testMoveToTail()
     CPPUNIT_ASSERT(bucket.addNode(nodes[i]));
   }
   bucket.moveToTail(nodes[0]);
-  CPPUNIT_ASSERT(bucket.getNodes().back() == nodes[0]);
+  CPPUNIT_ASSERT(*bucket.getNodes().back() == *nodes[0]);
 }
 
 void DHTBucketTest::testGetGoodNodes()
@@ -398,12 +402,12 @@ void DHTBucketTest::testCacheNode()
   bucket.cacheNode(n1);
   bucket.cacheNode(n2);
   CPPUNIT_ASSERT_EQUAL((size_t)2, bucket.getCachedNodes().size());
-  CPPUNIT_ASSERT(n2 == bucket.getCachedNodes()[0]);
+  CPPUNIT_ASSERT(*n2 == *bucket.getCachedNodes()[0]);
 
   bucket.cacheNode(n3);
   CPPUNIT_ASSERT_EQUAL((size_t)2, bucket.getCachedNodes().size());
-  CPPUNIT_ASSERT(n3 == bucket.getCachedNodes()[0]);
-  CPPUNIT_ASSERT(n2 == bucket.getCachedNodes()[1]);
+  CPPUNIT_ASSERT(*n3 == *bucket.getCachedNodes()[0]);
+  CPPUNIT_ASSERT(*n2 == *bucket.getCachedNodes()[1]);
 }
 
 void DHTBucketTest::testDropNode()
@@ -430,7 +434,7 @@ void DHTBucketTest::testDropNode()
   {
     std::deque<SharedHandle<DHTNode> > tnodes = bucket.getNodes();
     CPPUNIT_ASSERT_EQUAL((size_t)8, tnodes.size());
-    CPPUNIT_ASSERT(nodes[3] == tnodes[3]);
+    CPPUNIT_ASSERT(*nodes[3] == *tnodes[3]);
   }
 
   bucket.cacheNode(cachedNode1);
@@ -440,11 +444,32 @@ void DHTBucketTest::testDropNode()
   {
     std::deque<SharedHandle<DHTNode> > tnodes = bucket.getNodes();
     CPPUNIT_ASSERT_EQUAL((size_t)8, tnodes.size());
-    CPPUNIT_ASSERT(tnodes.end() == std::find(tnodes.begin(), tnodes.end(), nodes[3]));
-    CPPUNIT_ASSERT(cachedNode2 == tnodes[7]);
+    CPPUNIT_ASSERT(tnodes.end() ==
+                   std::find_if(tnodes.begin(), tnodes.end(),
+                                derefEqual(nodes[3])));
+    CPPUNIT_ASSERT(*cachedNode2 == *tnodes[7]);
   }
   CPPUNIT_ASSERT_EQUAL((size_t)1, bucket.getCachedNodes().size());
-  CPPUNIT_ASSERT(cachedNode1 == bucket.getCachedNodes()[0]);
+  CPPUNIT_ASSERT(*cachedNode1 == *bucket.getCachedNodes()[0]);
+}
+
+void DHTBucketTest::testGetNode()
+{
+  unsigned char localNodeID[DHT_ID_LENGTH];
+  memset(localNodeID, 0, DHT_ID_LENGTH);
+  SharedHandle<DHTNode> localNode(new DHTNode(localNodeID));
+  DHTBucket bucket(localNode);
+
+  unsigned char id[DHT_ID_LENGTH];
+  createID(id, 0xf0, 0);
+  SharedHandle<DHTNode> node(new DHTNode(id));
+  node->setIPAddress("192.168.0.1");
+  node->setPort(6881);
+  CPPUNIT_ASSERT(bucket.addNode(node));
+  CPPUNIT_ASSERT(bucket.getNode(id, "192.168.0.1", 6881));
+  CPPUNIT_ASSERT(!bucket.getNode(id, "192.168.0.2", 6881));
+  CPPUNIT_ASSERT(!bucket.getNode(id, "192.168.0.1", 6882));
+  CPPUNIT_ASSERT(!bucket.getNode(localNodeID, "192.168.0.1", 6881));
 }
 
 } // namespace aria2
